#include <SoftwareSerial.h>
#include <SimpleTimer.h>  // Put into sketchbook libraries folder

#define Rx      255       // No pin (receive not used)
#define Tx      11        // Pin D11
#define mixerA  0
#define mixerB  1

SoftwareSerial babble(Rx,Tx);
SimpleTimer  timer;

enum soundginPreset {
  SpaceWarp       = 0,		
  Waba            = 1,
  RandomThoughts  = 2,	
  Gong            = 3,	
  Pwang           = 4,	
  Wow             = 5,
  Rananana        = 6,	
  Twarty          = 7,	
  Telly           = 8,	
  Pulsator        = 9,	
  Bound           = 10,	
  TipToe          = 11,
  Spoles          = 12,	
  Chopper         = 13,	
  Phazer          = 14,	
  PowerLines      = 15,	
  HeavyMetal1     = 16,	
  HeavyMetal2     = 17,
  ACMotor         = 18,	
  YaYa            = 19,	
  March           = 20,	
  NoiseChatter    = 21,	
  BlipChatter     = 22,	
  Carney          = 23,
  EarthQuake      = 24,	
  MindProbe       = 25,	
  Siren           = 26,	
  Squaba          = 27,	
  SteamLoco       = 28, 
  FreqMod         = 29, 
  AmpMod          = 30
};


void setup() {
  // Be sure Babblebot is already powered
  babble.begin(9600);
  delay(500);            // Keep at 500 or higher for Babblebot
  
  // Load a preset into a mixer, and wait (using delay)
  loadPreset(mixerB, BlipChatter);
  delay(2000);          // Play for 2 seconds
  clearMixer(mixerB);

  // Load a preset unto mixerA, and allow timer to clear sound
  //   After this the loop function starts
  playSound(YaYa, 2000); //Play YaYa for 2 seconds
}

// Main loop
void loop() {
  timer.run();      // Check if timer has elapsed
}

// Play a preset using timer
//   Set timer delay, and specify function for clearing sound
void playSound(byte preset, int delayInterval) {
  loadPreset(mixerA, preset);
  timer.setTimeout(delayInterval, clearSound);
}

// Clear sound, mixerA hardcoded (use with timer)
void clearSound() {
  clearMixer(mixerA);
}

// Clear sound, specify mixer (overloaded function)
void clearSound(byte mixer) {
  clearMixer(mixer);
}

// Load a preset, specify mixer and preset
void loadPreset(byte mixer, byte presetSound) {
  babble.write((byte)0x1b);
  if(mixer == mixerA)
    babble.write((byte)0x4b);      // Load preset in mixer A
  else
    babble.write((byte)0x6b);      // Load preset in mixer B
  babble.write(presetSound);
  triggerMixer(mixer);
}

// Trigger (play) a preset
void triggerMixer(byte mixer) {
  babble.write((byte)0x1b);
  if(mixer == mixerA)
    babble.write((byte)0x53);      // Trigger mixer A  
  else
    babble.write((byte)0x73);      // Trigger mixer B
    
}

void clearMixer(byte mixer) {
  babble.write((byte)0x1b);
  if(mixer == mixerA)
    babble.write((byte)0x57);      // Clear mixer A
  else
    babble.write((byte)0x77);      // Clear mixer B
}

